@@ -20,9 +20,64 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include <gee/readonlylist.h>
+#include <glib.h>
+#include <glib-object.h>
 
 
+#define GEE_TYPE_COLLECTION_OBJECT (gee_collection_object_get_type ())
+#define GEE_COLLECTION_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_COLLECTION_OBJECT, GeeCollectionObject))
+#define GEE_COLLECTION_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_TYPE_COLLECTION_OBJECT, GeeCollectionObjectClass))
+#define GEE_IS_COLLECTION_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_COLLECTION_OBJECT))
+#define GEE_IS_COLLECTION_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_TYPE_COLLECTION_OBJECT))
+#define GEE_COLLECTION_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_TYPE_COLLECTION_OBJECT, GeeCollectionObjectClass))
+
+typedef struct _GeeCollectionObject GeeCollectionObject;
+typedef struct _GeeCollectionObjectClass GeeCollectionObjectClass;
+typedef struct _GeeCollectionObjectPrivate GeeCollectionObjectPrivate;
+
+#define GEE_TYPE_ITERABLE (gee_iterable_get_type ())
+#define GEE_ITERABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_ITERABLE, GeeIterable))
+#define GEE_IS_ITERABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_ITERABLE))
+#define GEE_ITERABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GEE_TYPE_ITERABLE, GeeIterableIface))
+
+typedef struct _GeeIterable GeeIterable;
+typedef struct _GeeIterableIface GeeIterableIface;
+
+#define GEE_TYPE_ITERATOR (gee_iterator_get_type ())
+#define GEE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_ITERATOR, GeeIterator))
+#define GEE_IS_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_ITERATOR))
+#define GEE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GEE_TYPE_ITERATOR, GeeIteratorIface))
+
+typedef struct _GeeIterator GeeIterator;
+typedef struct _GeeIteratorIface GeeIteratorIface;
+
+#define GEE_TYPE_COLLECTION (gee_collection_get_type ())
+#define GEE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_COLLECTION, GeeCollection))
+#define GEE_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_COLLECTION))
+#define GEE_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GEE_TYPE_COLLECTION, GeeCollectionIface))
+
+typedef struct _GeeCollection GeeCollection;
+typedef struct _GeeCollectionIface GeeCollectionIface;
+
+#define GEE_TYPE_LIST (gee_list_get_type ())
+#define GEE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_LIST, GeeList))
+#define GEE_IS_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_LIST))
+#define GEE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GEE_TYPE_LIST, GeeListIface))
+
+typedef struct _GeeList GeeList;
+typedef struct _GeeListIface GeeListIface;
+
+#define GEE_TYPE_READ_ONLY_LIST (gee_read_only_list_get_type ())
+#define GEE_READ_ONLY_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_READ_ONLY_LIST, GeeReadOnlyList))
+#define GEE_READ_ONLY_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_TYPE_READ_ONLY_LIST, GeeReadOnlyListClass))
+#define GEE_IS_READ_ONLY_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_READ_ONLY_LIST))
+#define GEE_IS_READ_ONLY_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_TYPE_READ_ONLY_LIST))
+#define GEE_READ_ONLY_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_TYPE_READ_ONLY_LIST, GeeReadOnlyListClass))
+
+typedef struct _GeeReadOnlyList GeeReadOnlyList;
+typedef struct _GeeReadOnlyListClass GeeReadOnlyListClass;
+typedef struct _GeeReadOnlyListPrivate GeeReadOnlyListPrivate;
+
 #define GEE_READ_ONLY_LIST_TYPE_ITERATOR (gee_read_only_list_iterator_get_type ())
 #define GEE_READ_ONLY_LIST_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_READ_ONLY_LIST_TYPE_ITERATOR, GeeReadOnlyListIterator))
 #define GEE_READ_ONLY_LIST_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_READ_ONLY_LIST_TYPE_ITERATOR, GeeReadOnlyListIteratorClass))
@@ -34,6 +89,84 @@ typedef struct _GeeReadOnlyListIterator GeeReadOnlyListIterator;
 typedef struct _GeeReadOnlyListIteratorClass GeeReadOnlyListIteratorClass;
 typedef struct _GeeReadOnlyListIteratorPrivate GeeReadOnlyListIteratorPrivate;
 
+/**
+ * Base class for all collections.
+ */
+struct _GeeCollectionObject {
+	GTypeInstance parent_instance;
+	volatile int ref_count;
+	GeeCollectionObjectPrivate * priv;
+};
+
+struct _GeeCollectionObjectClass {
+	GTypeClass parent_class;
+	void (*finalize) (GeeCollectionObject *self);
+};
+
+/**
+ * Implemented by classes that support a simple iteration over instances of the
+ * collection.
+ */
+struct _GeeIterableIface {
+	GTypeInterface parent_iface;
+	GType (*get_element_type) (GeeIterable* self);
+	GeeIterator* (*iterator) (GeeIterable* self);
+};
+
+/**
+ * Implemented by classes that support a simple iteration over instances of the
+ * collection.
+ */
+struct _GeeIteratorIface {
+	GTypeInterface parent_iface;
+	gboolean (*next) (GeeIterator* self);
+	gpointer (*get) (GeeIterator* self);
+};
+
+/**
+ * Serves as the base interface for implementing collection classes. Defines
+ * size, iteration, and modification methods.
+ */
+struct _GeeCollectionIface {
+	GTypeInterface parent_iface;
+	gboolean (*contains) (GeeCollection* self, gconstpointer item);
+	gboolean (*add) (GeeCollection* self, gconstpointer item);
+	gboolean (*remove) (GeeCollection* self, gconstpointer item);
+	void (*clear) (GeeCollection* self);
+	gint (*get_size) (GeeCollection* self);
+};
+
+/**
+ * Represents a collection of items in a well-defined order.
+ */
+struct _GeeListIface {
+	GTypeInterface parent_iface;
+	gpointer (*get) (GeeList* self, gint index);
+	void (*set) (GeeList* self, gint index, gconstpointer item);
+	gint (*index_of) (GeeList* self, gconstpointer item);
+	void (*insert) (GeeList* self, gint index, gconstpointer item);
+	void (*remove_at) (GeeList* self, gint index);
+};
+
+/**
+ * Represents a read-only collection of items in a well-defined order.
+ */
+struct _GeeReadOnlyList {
+	GeeCollectionObject parent_instance;
+	GeeReadOnlyListPrivate * priv;
+};
+
+struct _GeeReadOnlyListClass {
+	GeeCollectionObjectClass parent_class;
+};
+
+struct _GeeReadOnlyListPrivate {
+	GType g_type;
+	GBoxedCopyFunc g_dup_func;
+	GDestroyNotify g_destroy_func;
+	GeeList* _list;
+};
+
 struct _GeeReadOnlyListIterator {
 	GeeCollectionObject parent_instance;
 	GeeReadOnlyListIteratorPrivate * priv;
@@ -43,47 +176,61 @@ struct _GeeReadOnlyListIteratorClass {
 	GeeCollectionObjectClass parent_class;
 };
 
-
-
-struct _GeeReadOnlyListPrivate {
-	GeeList* _list;
-	GType g_type;
-	GBoxedCopyFunc g_dup_func;
-	GDestroyNotify g_destroy_func;
-};
-
-#define GEE_READ_ONLY_LIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_READ_ONLY_LIST, GeeReadOnlyListPrivate))
-enum  {
-	GEE_READ_ONLY_LIST_DUMMY_PROPERTY
-};
-static GType gee_read_only_list_real_get_element_type (GeeIterable* base);
-static GeeIterator* gee_read_only_list_real_iterator (GeeIterable* base);
-static gboolean gee_read_only_list_real_contains (GeeCollection* base, gconstpointer item);
-static gint gee_read_only_list_real_index_of (GeeList* base, gconstpointer item);
-static gboolean gee_read_only_list_real_add (GeeCollection* base, gconstpointer item);
-static gboolean gee_read_only_list_real_remove (GeeCollection* base, gconstpointer item);
-static void gee_read_only_list_real_insert (GeeList* base, gint index, gconstpointer item);
-static void gee_read_only_list_real_remove_at (GeeList* base, gint index);
-static gpointer gee_read_only_list_real_get (GeeList* base, gint index);
-static void gee_read_only_list_real_set (GeeList* base, gint index, gconstpointer o);
-static void gee_read_only_list_real_clear (GeeCollection* base);
 struct _GeeReadOnlyListIteratorPrivate {
 	GType g_type;
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
 };
 
+
+
+gpointer gee_collection_object_ref (gpointer instance);
+void gee_collection_object_unref (gpointer instance);
+GParamSpec* gee_param_spec_collection_object (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void gee_value_set_collection_object (GValue* value, gpointer v_object);
+gpointer gee_value_get_collection_object (const GValue* value);
+GType gee_collection_object_get_type (void);
+GType gee_iterator_get_type (void);
+GType gee_iterable_get_type (void);
+GType gee_collection_get_type (void);
+GType gee_list_get_type (void);
+GType gee_read_only_list_get_type (void);
+#define GEE_READ_ONLY_LIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_READ_ONLY_LIST, GeeReadOnlyListPrivate))
+enum  {
+	GEE_READ_ONLY_LIST_DUMMY_PROPERTY
+};
+void gee_read_only_list_set_list (GeeReadOnlyList* self, GeeList* value);
+GeeReadOnlyList* gee_read_only_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeList* list);
+GeeReadOnlyList* gee_read_only_list_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeList* list);
+GeeReadOnlyList* gee_read_only_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeList* list);
+static GType gee_read_only_list_real_get_element_type (GeeIterable* base);
+static GeeReadOnlyListIterator* gee_read_only_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
+static GeeReadOnlyListIterator* gee_read_only_list_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
+static GType gee_read_only_list_iterator_get_type (void);
+GeeIterator* gee_iterable_iterator (GeeIterable* self);
+static GeeIterator* gee_read_only_list_real_iterator (GeeIterable* base);
+gboolean gee_collection_contains (GeeCollection* self, gconstpointer item);
+static gboolean gee_read_only_list_real_contains (GeeCollection* base, gconstpointer item);
+gint gee_list_index_of (GeeList* self, gconstpointer item);
+static gint gee_read_only_list_real_index_of (GeeList* base, gconstpointer item);
+static gboolean gee_read_only_list_real_add (GeeCollection* base, gconstpointer item);
+static gboolean gee_read_only_list_real_remove (GeeCollection* base, gconstpointer item);
+static void gee_read_only_list_real_insert (GeeList* base, gint index, gconstpointer item);
+static void gee_read_only_list_real_remove_at (GeeList* base, gint index);
+gpointer gee_list_get (GeeList* self, gint index);
+static gpointer gee_read_only_list_real_get (GeeList* base, gint index);
+static void gee_read_only_list_real_set (GeeList* base, gint index, gconstpointer o);
+static void gee_read_only_list_real_clear (GeeCollection* base);
+gint gee_collection_get_size (GeeCollection* self);
 #define GEE_READ_ONLY_LIST_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_READ_ONLY_LIST_TYPE_ITERATOR, GeeReadOnlyListIteratorPrivate))
 enum  {
 	GEE_READ_ONLY_LIST_ITERATOR_DUMMY_PROPERTY
 };
 static gboolean gee_read_only_list_iterator_real_next (GeeIterator* base);
 static gpointer gee_read_only_list_iterator_real_get (GeeIterator* base);
-static GeeReadOnlyListIterator* gee_read_only_list_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
 static GeeReadOnlyListIterator* gee_read_only_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
 static gpointer gee_read_only_list_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_read_only_list_iterator_gee_iterator_parent_iface = NULL;
-static GType gee_read_only_list_iterator_get_type (void);
 static gpointer gee_read_only_list_parent_class = NULL;
 static GeeIterableIface* gee_read_only_list_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_read_only_list_gee_collection_parent_iface = NULL;
