@@ -20,23 +20,142 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include <vala/valacodenode.h>
-#include <gee/readonlylist.h>
-#include <gee/arraylist.h>
-#include <gee/iterable.h>
-#include <gee/iterator.h>
-#include <ccode/valaccodelinedirective.h>
-#include <vala/valasourcereference.h>
-#include <vala/valacodevisitor.h>
-#include <vala/valasemanticanalyzer.h>
-#include <vala/valaattribute.h>
-#include <vala/valadatatype.h>
-#include <vala/valaexpression.h>
-#include <vala/valasourcefile.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
+#include <gee.h>
+#include <valaccode.h>
 #include <gobject/gvaluecollector.h>
 
 
+#define VALA_TYPE_CODE_NODE (vala_code_node_get_type ())
+#define VALA_CODE_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CODE_NODE, ValaCodeNode))
+#define VALA_CODE_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CODE_NODE, ValaCodeNodeClass))
+#define VALA_IS_CODE_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CODE_NODE))
+#define VALA_IS_CODE_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CODE_NODE))
+#define VALA_CODE_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_NODE, ValaCodeNodeClass))
 
+typedef struct _ValaCodeNode ValaCodeNode;
+typedef struct _ValaCodeNodeClass ValaCodeNodeClass;
+typedef struct _ValaCodeNodePrivate ValaCodeNodePrivate;
+
+#define VALA_TYPE_CODE_VISITOR (vala_code_visitor_get_type ())
+#define VALA_CODE_VISITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CODE_VISITOR, ValaCodeVisitor))
+#define VALA_CODE_VISITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CODE_VISITOR, ValaCodeVisitorClass))
+#define VALA_IS_CODE_VISITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CODE_VISITOR))
+#define VALA_IS_CODE_VISITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CODE_VISITOR))
+#define VALA_CODE_VISITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_VISITOR, ValaCodeVisitorClass))
+
+typedef struct _ValaCodeVisitor ValaCodeVisitor;
+typedef struct _ValaCodeVisitorClass ValaCodeVisitorClass;
+
+#define VALA_TYPE_SEMANTIC_ANALYZER (vala_semantic_analyzer_get_type ())
+#define VALA_SEMANTIC_ANALYZER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SEMANTIC_ANALYZER, ValaSemanticAnalyzer))
+#define VALA_SEMANTIC_ANALYZER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SEMANTIC_ANALYZER, ValaSemanticAnalyzerClass))
+#define VALA_IS_SEMANTIC_ANALYZER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SEMANTIC_ANALYZER))
+#define VALA_IS_SEMANTIC_ANALYZER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SEMANTIC_ANALYZER))
+#define VALA_SEMANTIC_ANALYZER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SEMANTIC_ANALYZER, ValaSemanticAnalyzerClass))
+
+typedef struct _ValaSemanticAnalyzer ValaSemanticAnalyzer;
+typedef struct _ValaSemanticAnalyzerClass ValaSemanticAnalyzerClass;
+
+#define VALA_TYPE_DATA_TYPE (vala_data_type_get_type ())
+#define VALA_DATA_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_DATA_TYPE, ValaDataType))
+#define VALA_DATA_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_DATA_TYPE, ValaDataTypeClass))
+#define VALA_IS_DATA_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_DATA_TYPE))
+#define VALA_IS_DATA_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_DATA_TYPE))
+#define VALA_DATA_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_DATA_TYPE, ValaDataTypeClass))
+
+typedef struct _ValaDataType ValaDataType;
+typedef struct _ValaDataTypeClass ValaDataTypeClass;
+
+#define VALA_TYPE_EXPRESSION (vala_expression_get_type ())
+#define VALA_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_EXPRESSION, ValaExpression))
+#define VALA_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_EXPRESSION, ValaExpressionClass))
+#define VALA_IS_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_EXPRESSION))
+#define VALA_IS_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_EXPRESSION))
+#define VALA_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_EXPRESSION, ValaExpressionClass))
+
+typedef struct _ValaExpression ValaExpression;
+typedef struct _ValaExpressionClass ValaExpressionClass;
+
+#define VALA_TYPE_SYMBOL (vala_symbol_get_type ())
+#define VALA_SYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SYMBOL, ValaSymbol))
+#define VALA_SYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SYMBOL, ValaSymbolClass))
+#define VALA_IS_SYMBOL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SYMBOL))
+#define VALA_IS_SYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SYMBOL))
+#define VALA_SYMBOL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SYMBOL, ValaSymbolClass))
+
+typedef struct _ValaSymbol ValaSymbol;
+typedef struct _ValaSymbolClass ValaSymbolClass;
+
+#define VALA_TYPE_LOCAL_VARIABLE (vala_local_variable_get_type ())
+#define VALA_LOCAL_VARIABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LOCAL_VARIABLE, ValaLocalVariable))
+#define VALA_LOCAL_VARIABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LOCAL_VARIABLE, ValaLocalVariableClass))
+#define VALA_IS_LOCAL_VARIABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LOCAL_VARIABLE))
+#define VALA_IS_LOCAL_VARIABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LOCAL_VARIABLE))
+#define VALA_LOCAL_VARIABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LOCAL_VARIABLE, ValaLocalVariableClass))
+
+typedef struct _ValaLocalVariable ValaLocalVariable;
+typedef struct _ValaLocalVariableClass ValaLocalVariableClass;
+
+#define VALA_TYPE_ATTRIBUTE (vala_attribute_get_type ())
+#define VALA_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ATTRIBUTE, ValaAttribute))
+#define VALA_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ATTRIBUTE, ValaAttributeClass))
+#define VALA_IS_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ATTRIBUTE))
+#define VALA_IS_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ATTRIBUTE))
+#define VALA_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ATTRIBUTE, ValaAttributeClass))
+
+typedef struct _ValaAttribute ValaAttribute;
+typedef struct _ValaAttributeClass ValaAttributeClass;
+
+#define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
+#define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
+#define VALA_SOURCE_REFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReferenceClass))
+#define VALA_IS_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SOURCE_REFERENCE))
+#define VALA_IS_SOURCE_REFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SOURCE_REFERENCE))
+#define VALA_SOURCE_REFERENCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReferenceClass))
+
+typedef struct _ValaSourceReference ValaSourceReference;
+typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+
+#define VALA_TYPE_SOURCE_FILE (vala_source_file_get_type ())
+#define VALA_SOURCE_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_FILE, ValaSourceFile))
+#define VALA_SOURCE_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SOURCE_FILE, ValaSourceFileClass))
+#define VALA_IS_SOURCE_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SOURCE_FILE))
+#define VALA_IS_SOURCE_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SOURCE_FILE))
+#define VALA_SOURCE_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SOURCE_FILE, ValaSourceFileClass))
+
+typedef struct _ValaSourceFile ValaSourceFile;
+typedef struct _ValaSourceFileClass ValaSourceFileClass;
+typedef struct _ValaParamSpecCodeNode ValaParamSpecCodeNode;
+
+/**
+ * Represents a part of the parsed source code.
+ *
+ * Code nodes get created by the parser and are used throughout the whole
+ * compilation process.
+ */
+struct _ValaCodeNode {
+	GTypeInstance parent_instance;
+	volatile int ref_count;
+	ValaCodeNodePrivate * priv;
+	GList* attributes;
+};
+
+struct _ValaCodeNodeClass {
+	GTypeClass parent_class;
+	void (*finalize) (ValaCodeNode *self);
+	void (*accept) (ValaCodeNode* self, ValaCodeVisitor* visitor);
+	void (*accept_children) (ValaCodeNode* self, ValaCodeVisitor* visitor);
+	gboolean (*check) (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
+	void (*replace_type) (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
+	void (*replace_expression) (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node);
+	char* (*to_string) (ValaCodeNode* self);
+	void (*get_defined_variables) (ValaCodeNode* self, GeeCollection* collection);
+	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
+};
 
 struct _ValaCodeNodePrivate {
 	ValaCodeNode* _parent_node;
@@ -47,21 +166,89 @@ struct _ValaCodeNodePrivate {
 	ValaCCodeNode* _ccodenode;
 };
 
+struct _ValaParamSpecCodeNode {
+	GParamSpec parent_instance;
+};
+
+
+
+gpointer vala_code_node_ref (gpointer instance);
+void vala_code_node_unref (gpointer instance);
+GParamSpec* vala_param_spec_code_node (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_code_node (GValue* value, gpointer v_object);
+gpointer vala_value_get_code_node (const GValue* value);
+GType vala_code_node_get_type (void);
+gpointer vala_code_visitor_ref (gpointer instance);
+void vala_code_visitor_unref (gpointer instance);
+GParamSpec* vala_param_spec_code_visitor (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_code_visitor (GValue* value, gpointer v_object);
+gpointer vala_value_get_code_visitor (const GValue* value);
+GType vala_code_visitor_get_type (void);
+GType vala_semantic_analyzer_get_type (void);
+GType vala_data_type_get_type (void);
+GType vala_expression_get_type (void);
+GType vala_symbol_get_type (void);
+GType vala_local_variable_get_type (void);
+GType vala_attribute_get_type (void);
+gpointer vala_source_reference_ref (gpointer instance);
+void vala_source_reference_unref (gpointer instance);
+GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_source_reference (GValue* value, gpointer v_object);
+gpointer vala_value_get_source_reference (const GValue* value);
+GType vala_source_reference_get_type (void);
 #define VALA_CODE_NODE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CODE_NODE, ValaCodeNodePrivate))
 enum  {
 	VALA_CODE_NODE_DUMMY_PROPERTY
 };
 static void _g_list_free_vala_code_node_unref (GList* self);
+static GeeList* vala_code_node__empty_type_list;
 static GeeList* vala_code_node__empty_type_list = NULL;
+static gint vala_code_node_last_temp_nr;
 static gint vala_code_node_last_temp_nr = 0;
+GeeList* vala_code_node_get_error_types (ValaCodeNode* self);
+void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
+void vala_code_node_add_error_type (ValaCodeNode* self, ValaDataType* error_type);
+void vala_code_node_add_error_types (ValaCodeNode* self, GeeList* error_types);
+void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 static void vala_code_node_real_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
+void vala_code_node_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor);
 static void vala_code_node_real_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor);
+gboolean vala_code_node_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
 static gboolean vala_code_node_real_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
+void vala_code_node_replace_type (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
 static void vala_code_node_real_replace_type (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
+void vala_code_node_replace_expression (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node);
 static void vala_code_node_real_replace_expression (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node);
+const char* vala_attribute_get_name (ValaAttribute* self);
+ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* name);
+ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
+char* vala_source_reference_to_string (ValaSourceReference* self);
+char* vala_code_node_to_string (ValaCodeNode* self);
 static char* vala_code_node_real_to_string (ValaCodeNode* self);
+void vala_code_node_get_defined_variables (ValaCodeNode* self, GeeCollection* collection);
 static void vala_code_node_real_get_defined_variables (ValaCodeNode* self, GeeCollection* collection);
+void vala_code_node_get_used_variables (ValaCodeNode* self, GeeCollection* collection);
 static void vala_code_node_real_get_used_variables (ValaCodeNode* self, GeeCollection* collection);
+char* vala_code_node_get_temp_name (ValaCodeNode* self);
+ValaCodeNode* vala_code_node_get_parent_node (ValaCodeNode* self);
+void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
+const char* vala_code_node_get_type_name (ValaCodeNode* self);
+ValaCCodeNode* vala_code_node_get_ccodenode (ValaCodeNode* self);
+gpointer vala_source_file_ref (gpointer instance);
+void vala_source_file_unref (gpointer instance);
+GParamSpec* vala_param_spec_source_file (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_source_file (GValue* value, gpointer v_object);
+gpointer vala_value_get_source_file (const GValue* value);
+GType vala_source_file_get_type (void);
+ValaSourceFile* vala_source_reference_get_file (ValaSourceReference* self);
+const char* vala_source_file_get_filename (ValaSourceFile* self);
+gint vala_source_reference_get_first_line (ValaSourceReference* self);
+void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value);
+gboolean vala_code_node_get_checked (ValaCodeNode* self);
+void vala_code_node_set_checked (ValaCodeNode* self, gboolean value);
+gboolean vala_code_node_get_error (ValaCodeNode* self);
+void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
+gboolean vala_code_node_get_tree_can_fail (ValaCodeNode* self);
 static gpointer vala_code_node_parent_class = NULL;
 static void vala_code_node_finalize (ValaCodeNode* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
@@ -292,13 +479,7 @@ char* vala_code_node_get_temp_name (ValaCodeNode* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_strconcat (".", _tmp0 = g_strdup_printf ("%i", ((vala_code_node_last_temp_nr = vala_code_node_last_temp_nr + 1))), NULL), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
-}
-
-
-const char* vala_code_node_get_type_name (ValaCodeNode* self) {
-	g_return_val_if_fail (self != NULL, NULL);
-	return g_type_name (G_TYPE_FROM_INSTANCE (self));
+	return (_tmp1 = g_strconcat (".", _tmp0 = g_strdup_printf ("%i", vala_code_node_last_temp_nr = vala_code_node_last_temp_nr + 1), NULL), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
 }
 
 
@@ -330,6 +511,12 @@ void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReferenc
 }
 
 
+const char* vala_code_node_get_type_name (ValaCodeNode* self) {
+	g_return_val_if_fail (self != NULL, NULL);
+	return g_type_name (G_TYPE_FROM_INSTANCE (self));
+}
+
+
 ValaCCodeNode* vala_code_node_get_ccodenode (ValaCodeNode* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_ccodenode;
