@@ -21,13 +21,198 @@
  * 	Jamie McCracken jamiemcc gnome org
  */
 
-#include <vala/valageniescanner.h>
-#include <vala/valareport.h>
-#include <vala/valasourcereference.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
 #include <gobject/gvaluecollector.h>
 
 
+#define VALA_GENIE_TYPE_SCANNER (vala_genie_scanner_get_type ())
+#define VALA_GENIE_SCANNER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_GENIE_TYPE_SCANNER, ValaGenieScanner))
+#define VALA_GENIE_SCANNER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_GENIE_TYPE_SCANNER, ValaGenieScannerClass))
+#define VALA_GENIE_IS_SCANNER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_GENIE_TYPE_SCANNER))
+#define VALA_GENIE_IS_SCANNER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_GENIE_TYPE_SCANNER))
+#define VALA_GENIE_SCANNER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_GENIE_TYPE_SCANNER, ValaGenieScannerClass))
 
+typedef struct _ValaGenieScanner ValaGenieScanner;
+typedef struct _ValaGenieScannerClass ValaGenieScannerClass;
+typedef struct _ValaGenieScannerPrivate ValaGenieScannerPrivate;
+
+#define VALA_TYPE_SOURCE_FILE (vala_source_file_get_type ())
+#define VALA_SOURCE_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_FILE, ValaSourceFile))
+#define VALA_SOURCE_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SOURCE_FILE, ValaSourceFileClass))
+#define VALA_IS_SOURCE_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SOURCE_FILE))
+#define VALA_IS_SOURCE_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SOURCE_FILE))
+#define VALA_SOURCE_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SOURCE_FILE, ValaSourceFileClass))
+
+typedef struct _ValaSourceFile ValaSourceFile;
+typedef struct _ValaSourceFileClass ValaSourceFileClass;
+
+#define VALA_GENIE_TYPE_TOKEN_TYPE (vala_genie_token_type_get_type ())
+
+#define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
+#define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
+#define VALA_SOURCE_REFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReferenceClass))
+#define VALA_IS_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SOURCE_REFERENCE))
+#define VALA_IS_SOURCE_REFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SOURCE_REFERENCE))
+#define VALA_SOURCE_REFERENCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReferenceClass))
+
+typedef struct _ValaSourceReference ValaSourceReference;
+typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+typedef struct _ValaSourceLocation ValaSourceLocation;
+typedef struct _ValaGenieParamSpecScanner ValaGenieParamSpecScanner;
+
+/**
+ * Lexical scanner for Genie source files.
+ */
+struct _ValaGenieScanner {
+	GTypeInstance parent_instance;
+	volatile int ref_count;
+	ValaGenieScannerPrivate * priv;
+};
+
+struct _ValaGenieScannerClass {
+	GTypeClass parent_class;
+	void (*finalize) (ValaGenieScanner *self);
+};
+
+typedef enum  {
+	VALA_GENIE_TOKEN_TYPE_NONE,
+	VALA_GENIE_TOKEN_TYPE_ABSTRACT,
+	VALA_GENIE_TOKEN_TYPE_ARRAY,
+	VALA_GENIE_TOKEN_TYPE_AS,
+	VALA_GENIE_TOKEN_TYPE_ASSERT,
+	VALA_GENIE_TOKEN_TYPE_ASSIGN,
+	VALA_GENIE_TOKEN_TYPE_ASSIGN_ADD,
+	VALA_GENIE_TOKEN_TYPE_ASSIGN_BITWISE_AND,
+	VALA_GENIE_TOKEN_TYPE_ASSIGN_BITWISE_OR,
+	VALA_GENIE_TOKEN_TYPE_ASSIGN_BITWISE_XOR,
+	VALA_GENIE_TOKEN_TYPE_ASSIGN_DIV,
+	VALA_GENIE_TOKEN_TYPE_ASSIGN_MUL,
+	VALA_GENIE_TOKEN_TYPE_ASSIGN_PERCENT,
+	VALA_GENIE_TOKEN_TYPE_ASSIGN_SHIFT_LEFT,
+	VALA_GENIE_TOKEN_TYPE_ASSIGN_SUB,
+	VALA_GENIE_TOKEN_TYPE_BITWISE_AND,
+	VALA_GENIE_TOKEN_TYPE_BITWISE_OR,
+	VALA_GENIE_TOKEN_TYPE_BREAK,
+	VALA_GENIE_TOKEN_TYPE_CARRET,
+	VALA_GENIE_TOKEN_TYPE_CASE,
+	VALA_GENIE_TOKEN_TYPE_CHARACTER_LITERAL,
+	VALA_GENIE_TOKEN_TYPE_CLASS,
+	VALA_GENIE_TOKEN_TYPE_CLOSE_BRACE,
+	VALA_GENIE_TOKEN_TYPE_CLOSE_BRACKET,
+	VALA_GENIE_TOKEN_TYPE_CLOSE_PARENS,
+	VALA_GENIE_TOKEN_TYPE_COLON,
+	VALA_GENIE_TOKEN_TYPE_COMMA,
+	VALA_GENIE_TOKEN_TYPE_CONST,
+	VALA_GENIE_TOKEN_TYPE_CONSTRUCT,
+	VALA_GENIE_TOKEN_TYPE_CONTINUE,
+	VALA_GENIE_TOKEN_TYPE_DEDENT,
+	VALA_GENIE_TOKEN_TYPE_DEF,
+	VALA_GENIE_TOKEN_TYPE_DEFAULT,
+	VALA_GENIE_TOKEN_TYPE_DELEGATE,
+	VALA_GENIE_TOKEN_TYPE_DELETE,
+	VALA_GENIE_TOKEN_TYPE_DICT,
+	VALA_GENIE_TOKEN_TYPE_DIV,
+	VALA_GENIE_TOKEN_TYPE_DO,
+	VALA_GENIE_TOKEN_TYPE_DOT,
+	VALA_GENIE_TOKEN_TYPE_DOWNTO,
+	VALA_GENIE_TOKEN_TYPE_DYNAMIC,
+	VALA_GENIE_TOKEN_TYPE_ELLIPSIS,
+	VALA_GENIE_TOKEN_TYPE_ELSE,
+	VALA_GENIE_TOKEN_TYPE_ENUM,
+	VALA_GENIE_TOKEN_TYPE_ENSURES,
+	VALA_GENIE_TOKEN_TYPE_ERRORDOMAIN,
+	VALA_GENIE_TOKEN_TYPE_EOF,
+	VALA_GENIE_TOKEN_TYPE_EOL,
+	VALA_GENIE_TOKEN_TYPE_EVENT,
+	VALA_GENIE_TOKEN_TYPE_EXCEPT,
+	VALA_GENIE_TOKEN_TYPE_EXTERN,
+	VALA_GENIE_TOKEN_TYPE_FALSE,
+	VALA_GENIE_TOKEN_TYPE_FINAL,
+	VALA_GENIE_TOKEN_TYPE_FINALLY,
+	VALA_GENIE_TOKEN_TYPE_FOR,
+	VALA_GENIE_TOKEN_TYPE_FOREACH,
+	VALA_GENIE_TOKEN_TYPE_GET,
+	VALA_GENIE_TOKEN_TYPE_HASH,
+	VALA_GENIE_TOKEN_TYPE_IDENTIFIER,
+	VALA_GENIE_TOKEN_TYPE_IF,
+	VALA_GENIE_TOKEN_TYPE_IMPLEMENTS,
+	VALA_GENIE_TOKEN_TYPE_IN,
+	VALA_GENIE_TOKEN_TYPE_INDENT,
+	VALA_GENIE_TOKEN_TYPE_INIT,
+	VALA_GENIE_TOKEN_TYPE_INLINE,
+	VALA_GENIE_TOKEN_TYPE_INTEGER_LITERAL,
+	VALA_GENIE_TOKEN_TYPE_INTERFACE,
+	VALA_GENIE_TOKEN_TYPE_INTERR,
+	VALA_GENIE_TOKEN_TYPE_IS,
+	VALA_GENIE_TOKEN_TYPE_ISA,
+	VALA_GENIE_TOKEN_TYPE_LAMBDA,
+	VALA_GENIE_TOKEN_TYPE_LIST,
+	VALA_GENIE_TOKEN_TYPE_LOCK,
+	VALA_GENIE_TOKEN_TYPE_MINUS,
+	VALA_GENIE_TOKEN_TYPE_NAMESPACE,
+	VALA_GENIE_TOKEN_TYPE_NEW,
+	VALA_GENIE_TOKEN_TYPE_NULL,
+	VALA_GENIE_TOKEN_TYPE_OF,
+	VALA_GENIE_TOKEN_TYPE_OUT,
+	VALA_GENIE_TOKEN_TYPE_OP_AND,
+	VALA_GENIE_TOKEN_TYPE_OP_DEC,
+	VALA_GENIE_TOKEN_TYPE_OP_EQ,
+	VALA_GENIE_TOKEN_TYPE_OP_GE,
+	VALA_GENIE_TOKEN_TYPE_OP_GT,
+	VALA_GENIE_TOKEN_TYPE_OP_INC,
+	VALA_GENIE_TOKEN_TYPE_OP_LE,
+	VALA_GENIE_TOKEN_TYPE_OP_LT,
+	VALA_GENIE_TOKEN_TYPE_OP_NE,
+	VALA_GENIE_TOKEN_TYPE_OP_NEG,
+	VALA_GENIE_TOKEN_TYPE_OP_OR,
+	VALA_GENIE_TOKEN_TYPE_OP_PTR,
+	VALA_GENIE_TOKEN_TYPE_OP_SHIFT_LEFT,
+	VALA_GENIE_TOKEN_TYPE_OPEN_BRACE,
+	VALA_GENIE_TOKEN_TYPE_OPEN_BRACKET,
+	VALA_GENIE_TOKEN_TYPE_OPEN_PARENS,
+	VALA_GENIE_TOKEN_TYPE_OVERRIDE,
+	VALA_GENIE_TOKEN_TYPE_PASS,
+	VALA_GENIE_TOKEN_TYPE_PERCENT,
+	VALA_GENIE_TOKEN_TYPE_PLUS,
+	VALA_GENIE_TOKEN_TYPE_PRINT,
+	VALA_GENIE_TOKEN_TYPE_PRIVATE,
+	VALA_GENIE_TOKEN_TYPE_PROP,
+	VALA_GENIE_TOKEN_TYPE_PROTECTED,
+	VALA_GENIE_TOKEN_TYPE_PUBLIC,
+	VALA_GENIE_TOKEN_TYPE_RAISE,
+	VALA_GENIE_TOKEN_TYPE_RAISES,
+	VALA_GENIE_TOKEN_TYPE_REAL_LITERAL,
+	VALA_GENIE_TOKEN_TYPE_READONLY,
+	VALA_GENIE_TOKEN_TYPE_REF,
+	VALA_GENIE_TOKEN_TYPE_REQUIRES,
+	VALA_GENIE_TOKEN_TYPE_RETURN,
+	VALA_GENIE_TOKEN_TYPE_SEMICOLON,
+	VALA_GENIE_TOKEN_TYPE_SET,
+	VALA_GENIE_TOKEN_TYPE_SIZEOF,
+	VALA_GENIE_TOKEN_TYPE_STAR,
+	VALA_GENIE_TOKEN_TYPE_STATIC,
+	VALA_GENIE_TOKEN_TYPE_STRING_LITERAL,
+	VALA_GENIE_TOKEN_TYPE_STRUCT,
+	VALA_GENIE_TOKEN_TYPE_SUPER,
+	VALA_GENIE_TOKEN_TYPE_THIS,
+	VALA_GENIE_TOKEN_TYPE_TILDE,
+	VALA_GENIE_TOKEN_TYPE_TO,
+	VALA_GENIE_TOKEN_TYPE_TRUE,
+	VALA_GENIE_TOKEN_TYPE_TRY,
+	VALA_GENIE_TOKEN_TYPE_TYPEOF,
+	VALA_GENIE_TOKEN_TYPE_USES,
+	VALA_GENIE_TOKEN_TYPE_VAR,
+	VALA_GENIE_TOKEN_TYPE_VIRTUAL,
+	VALA_GENIE_TOKEN_TYPE_VOID,
+	VALA_GENIE_TOKEN_TYPE_VOLATILE,
+	VALA_GENIE_TOKEN_TYPE_WEAK,
+	VALA_GENIE_TOKEN_TYPE_WHEN,
+	VALA_GENIE_TOKEN_TYPE_WHILE,
+	VALA_GENIE_TOKEN_TYPE_WRITEONLY
+} ValaGenieTokenType;
 
 struct _ValaGenieScannerPrivate {
 	ValaSourceFile* _source_file;
@@ -45,23 +230,71 @@ struct _ValaGenieScannerPrivate {
 	char* _comment;
 };
 
+/**
+ * Represents a position in a source file.
+ */
+struct _ValaSourceLocation {
+	gchar* pos;
+	gint line;
+	gint column;
+};
+
+struct _ValaGenieParamSpecScanner {
+	GParamSpec parent_instance;
+};
+
+
+
+gpointer vala_genie_scanner_ref (gpointer instance);
+void vala_genie_scanner_unref (gpointer instance);
+GParamSpec* vala_genie_param_spec_scanner (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_genie_value_set_scanner (GValue* value, gpointer v_object);
+gpointer vala_genie_value_get_scanner (const GValue* value);
+GType vala_genie_scanner_get_type (void);
+gpointer vala_source_file_ref (gpointer instance);
+void vala_source_file_unref (gpointer instance);
+GParamSpec* vala_param_spec_source_file (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_source_file (GValue* value, gpointer v_object);
+gpointer vala_value_get_source_file (const GValue* value);
+GType vala_source_file_get_type (void);
+GType vala_genie_token_type_get_type (void);
 #define VALA_GENIE_SCANNER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_GENIE_TYPE_SCANNER, ValaGenieScannerPrivate))
 enum  {
 	VALA_GENIE_SCANNER_DUMMY_PROPERTY
 };
+static void vala_genie_scanner_set_source_file (ValaGenieScanner* self, ValaSourceFile* value);
+gchar* vala_source_file_get_mapped_contents (ValaSourceFile* self);
+gsize vala_source_file_get_mapped_length (ValaSourceFile* self);
+ValaGenieScanner* vala_genie_scanner_new (ValaSourceFile* source_file);
+ValaGenieScanner* vala_genie_scanner_construct (GType object_type, ValaSourceFile* source_file);
+ValaGenieScanner* vala_genie_scanner_new (ValaSourceFile* source_file);
 static gboolean vala_genie_scanner_is_ident_char (ValaGenieScanner* self, gchar c);
-static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGenieScanner* self, gchar* begin, gint len);
-static gint vala_genie_scanner_count_tabs (ValaGenieScanner* self);
 static gboolean vala_genie_scanner_matches (ValaGenieScanner* self, gchar* begin, const char* keyword);
-static gboolean vala_genie_scanner_whitespace (ValaGenieScanner* self);
+static ValaGenieTokenType vala_genie_scanner_get_identifier_or_keyword (ValaGenieScanner* self, gchar* begin, gint len);
+static void vala_genie_scanner_space (ValaGenieScanner* self);
+static void vala_genie_scanner_skip_space_tabs (ValaGenieScanner* self);
 static inline gboolean vala_genie_scanner_newline (ValaGenieScanner* self);
 static gboolean vala_genie_scanner_skip_newlines (ValaGenieScanner* self);
+static gint vala_genie_scanner_count_tabs (ValaGenieScanner* self);
+gpointer vala_source_reference_ref (gpointer instance);
+void vala_source_reference_unref (gpointer instance);
+GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_source_reference (GValue* value, gpointer v_object);
+gpointer vala_value_get_source_reference (const GValue* value);
+GType vala_source_reference_get_type (void);
+void vala_report_error (ValaSourceReference* source, const char* message);
+ValaSourceFile* vala_genie_scanner_get_source_file (ValaGenieScanner* self);
+ValaSourceReference* vala_source_reference_new (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column);
+ValaSourceReference* vala_source_reference_construct (GType object_type, ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column);
+ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSourceLocation* token_begin, ValaSourceLocation* token_end);
+static gboolean vala_genie_scanner_whitespace (ValaGenieScanner* self);
+static void vala_genie_scanner_push_comment (ValaGenieScanner* self, const char* comment_item, gboolean file_comment);
 static gboolean vala_genie_scanner_comment (ValaGenieScanner* self);
 static gboolean vala_genie_scanner_skip_tabs (ValaGenieScanner* self);
-static void vala_genie_scanner_skip_space_tabs (ValaGenieScanner* self);
-static void vala_genie_scanner_space (ValaGenieScanner* self);
-static void vala_genie_scanner_push_comment (ValaGenieScanner* self, const char* comment_item, gboolean file_comment);
-static void vala_genie_scanner_set_source_file (ValaGenieScanner* self, ValaSourceFile* value);
+void vala_source_file_set_comment (ValaSourceFile* self, const char* value);
+char* vala_genie_scanner_pop_comment (ValaGenieScanner* self);
+gint vala_genie_scanner_get_indent_spaces (ValaGenieScanner* self);
+void vala_genie_scanner_set_indent_spaces (ValaGenieScanner* self, gint value);
 static gpointer vala_genie_scanner_parent_class = NULL;
 static void vala_genie_scanner_finalize (ValaGenieScanner* obj);
 
@@ -101,7 +334,7 @@ static gboolean vala_genie_scanner_is_ident_char (ValaGenieScanner* self, gchar
 	} else {
 		_tmp0 = c == '_';
 	}
-	return (_tmp0);
+	return _tmp0;
 }
 
 
@@ -846,10 +1079,10 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 		return VALA_GENIE_TOKEN_TYPE_DEDENT;
 	}
 	_tmp1 = FALSE;
-	if ((self->priv->_indent_spaces == 0)) {
+	if (self->priv->_indent_spaces == 0) {
 		_tmp1 = TRUE;
 	} else {
-		_tmp1 = (self->priv->last_token != VALA_GENIE_TOKEN_TYPE_EOL);
+		_tmp1 = self->priv->last_token != VALA_GENIE_TOKEN_TYPE_EOL;
 	}
 	if (_tmp1) {
 		/* scrub whitespace (excluding newlines) and comments */
@@ -873,7 +1106,7 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 		if (!_tmp2) {
 			break;
 		}
-		self->priv->current = self->priv->current + (2);
+		self->priv->current = self->priv->current + 2;
 		self->priv->line++;
 		vala_genie_scanner_skip_space_tabs (self);
 	}
@@ -925,7 +1158,7 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 		} else {
 			if (self->priv->current_indent_level < self->priv->indent_level) {
 				self->priv->indent_level--;
-				self->priv->pending_dedents = (self->priv->indent_level - self->priv->current_indent_level);
+				self->priv->pending_dedents = self->priv->indent_level - self->priv->current_indent_level;
 				(*token_end).pos = self->priv->current;
 				(*token_end).line = self->priv->line;
 				(*token_end).column = self->priv->column;
@@ -980,9 +1213,9 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 				gint len;
 				len = 0;
 				if (self->priv->current[1] == '@') {
-					(*token_begin).pos = (*token_begin).pos + (2);
+					(*token_begin).pos = (*token_begin).pos + 2;
 					/* @@ is not part of the identifier*/
-					self->priv->current = self->priv->current + (2);
+					self->priv->current = self->priv->current + 2;
 				} else {
 					self->priv->current++;
 					len = 1;
@@ -1117,7 +1350,7 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 										} else {
 											_tmp24 = self->priv->current[0] == '-';
 										}
-										_tmp23 = (_tmp24);
+										_tmp23 = _tmp24;
 									} else {
 										_tmp23 = FALSE;
 									}
@@ -1273,7 +1506,7 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 								}
 								if (_tmp34) {
 									type = VALA_GENIE_TOKEN_TYPE_ELLIPSIS;
-									self->priv->current = self->priv->current + (2);
+									self->priv->current = self->priv->current + 2;
 								}
 							}
 							break;
@@ -1624,9 +1857,9 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 										break;
 									} else {
 										gunichar u;
-										u = g_utf8_get_char_validated (((const char*) self->priv->current), (glong) (self->priv->end - self->priv->current));
+										u = g_utf8_get_char_validated ((const char*) self->priv->current, (glong) (self->priv->end - self->priv->current));
 										if (u != ((gunichar) (-1))) {
-											self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
+											self->priv->current = self->priv->current + g_unichar_to_utf8 (u, NULL);
 											token_length_in_chars++;
 										} else {
 											ValaSourceReference* _tmp45;
@@ -1659,10 +1892,10 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 						default:
 						{
 							gunichar u;
-							u = g_utf8_get_char_validated (((const char*) self->priv->current), (glong) (self->priv->end - self->priv->current));
+							u = g_utf8_get_char_validated ((const char*) self->priv->current, (glong) (self->priv->end - self->priv->current));
 							if (u != ((gunichar) (-1))) {
 								ValaSourceReference* _tmp49;
-								self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
+								self->priv->current = self->priv->current + g_unichar_to_utf8 (u, NULL);
 								_tmp49 = NULL;
 								vala_report_error (_tmp49 = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "syntax error, unexpected character");
 								(_tmp49 == NULL) ? NULL : (_tmp49 = (vala_source_reference_unref (_tmp49), NULL));
@@ -1685,7 +1918,7 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 	if (token_length_in_chars < 0) {
 		self->priv->column = self->priv->column + ((gint) (self->priv->current - begin));
 	} else {
-		self->priv->column = self->priv->column + (token_length_in_chars);
+		self->priv->column = self->priv->column + token_length_in_chars;
 	}
 	(*token_end).pos = self->priv->current;
 	(*token_end).line = self->priv->line;
@@ -1739,8 +1972,8 @@ static gint vala_genie_scanner_count_tabs (ValaGenieScanner* self) {
 	/* ignore comments and whitspace and other lines that contain no code */
 	vala_genie_scanner_space (self);
 	_tmp2 = FALSE;
-	if ((self->priv->current < self->priv->end)) {
-		_tmp2 = (self->priv->current[0] == '\n');
+	if (self->priv->current < self->priv->end) {
+		_tmp2 = self->priv->current[0] == '\n';
 	} else {
 		_tmp2 = FALSE;
 	}
@@ -1846,7 +2079,7 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 		} else {
 			_tmp2 = FALSE;
 		}
-		_tmp0 = (_tmp2);
+		_tmp0 = _tmp2;
 	}
 	if (_tmp0) {
 		return FALSE;
@@ -1855,7 +2088,7 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 		gchar* begin;
 		char* _tmp5;
 		/* single-line comment*/
-		self->priv->current = self->priv->current + (2);
+		self->priv->current = self->priv->current + 2;
 		begin = self->priv->current;
 		while (TRUE) {
 			gboolean _tmp4;
@@ -1871,7 +2104,7 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 			self->priv->current++;
 		}
 		_tmp5 = NULL;
-		vala_genie_scanner_push_comment (self, _tmp5 = g_strndup (((const char*) begin), (gsize) ((glong) (self->priv->current - begin))), self->priv->line == 1);
+		vala_genie_scanner_push_comment (self, _tmp5 = g_strndup ((const char*) begin, (gsize) ((glong) (self->priv->current - begin))), self->priv->line == 1);
 		_tmp5 = (g_free (_tmp5), NULL);
 		if (self->priv->current[0] == '\n') {
 			self->priv->current++;
@@ -1884,7 +2117,7 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 		gint begin_line;
 		char* _tmp10;
 		/* delimited comment*/
-		self->priv->current = self->priv->current + (2);
+		self->priv->current = self->priv->current + 2;
 		begin = self->priv->current;
 		begin_line = self->priv->line;
 		while (TRUE) {
@@ -1898,7 +2131,7 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 				} else {
 					_tmp7 = self->priv->current[1] != '/';
 				}
-				_tmp6 = (_tmp7);
+				_tmp6 = _tmp7;
 			} else {
 				_tmp6 = FALSE;
 			}
@@ -1920,10 +2153,10 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 			return TRUE;
 		}
 		_tmp10 = NULL;
-		vala_genie_scanner_push_comment (self, _tmp10 = g_strndup (((const char*) begin), (gsize) ((glong) (self->priv->current - begin))), begin_line == 1);
+		vala_genie_scanner_push_comment (self, _tmp10 = g_strndup ((const char*) begin, (gsize) ((glong) (self->priv->current - begin))), begin_line == 1);
 		_tmp10 = (g_free (_tmp10), NULL);
-		self->priv->current = self->priv->current + (2);
-		self->priv->column = self->priv->column + (2);
+		self->priv->current = self->priv->current + 2;
+		self->priv->column = self->priv->column + 2;
 	}
 	return TRUE;
 }
@@ -2022,7 +2255,7 @@ static void vala_genie_scanner_push_comment (ValaGenieScanner* self, const char*
  * @return saved comment
  */
 char* vala_genie_scanner_pop_comment (ValaGenieScanner* self) {
-	GString* result;
+	GString* result_builder;
 	char* _tmp1;
 	const char* index;
 	const char* _tmp2;
@@ -2031,16 +2264,16 @@ char* vala_genie_scanner_pop_comment (ValaGenieScanner* self) {
 	if (self->priv->_comment == NULL) {
 		return NULL;
 	}
-	result = g_string_new (self->priv->_comment);
+	result_builder = g_string_new (self->priv->_comment);
 	_tmp1 = NULL;
 	self->priv->_comment = (_tmp1 = NULL, self->priv->_comment = (g_free (self->priv->_comment), NULL), _tmp1);
 	index = NULL;
-	while ((index = g_utf8_strchr (result->str, (glong) (-1), (gunichar) '\t')) != NULL) {
-		g_string_erase (result, g_utf8_pointer_to_offset (result->str, index), (glong) 1);
+	while ((index = g_utf8_strchr (result_builder->str, (glong) (-1), (gunichar) '\t')) != NULL) {
+		g_string_erase (result_builder, g_utf8_pointer_to_offset (result_builder->str, index), (glong) 1);
 	}
 	_tmp2 = NULL;
 	_tmp3 = NULL;
-	return (_tmp3 = (_tmp2 = result->str, (_tmp2 == NULL) ? NULL : g_strdup (_tmp2)), (result == NULL) ? NULL : (result = (g_string_free (result, TRUE), NULL)), _tmp3);
+	return (_tmp3 = (_tmp2 = result_builder->str, (_tmp2 == NULL) ? NULL : g_strdup (_tmp2)), (result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL)), _tmp3);
 }
 
 
