@@ -20,32 +20,313 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include <vala/valanamespace.h>
-#include <gee/arraylist.h>
-#include <gee/collection.h>
-#include <gee/iterable.h>
-#include <gee/iterator.h>
-#include <gee/readonlylist.h>
-#include <vala/valasourcereference.h>
-#include <vala/valasemanticanalyzer.h>
-#include <vala/valaattribute.h>
-#include <vala/valacodevisitor.h>
-#include <vala/valaclass.h>
-#include <vala/valainterface.h>
-#include <vala/valastruct.h>
-#include <vala/valaenum.h>
-#include <vala/valaerrordomain.h>
-#include <vala/valadelegate.h>
-#include <vala/valaconstant.h>
-#include <vala/valafield.h>
-#include <vala/valamethod.h>
-#include <vala/valascope.h>
-#include <vala/valamember.h>
-#include <vala/valareport.h>
-#include <vala/valacreationmethod.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
+#include <gee.h>
 
 
+#define VALA_TYPE_CODE_NODE (vala_code_node_get_type ())
+#define VALA_CODE_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CODE_NODE, ValaCodeNode))
+#define VALA_CODE_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CODE_NODE, ValaCodeNodeClass))
+#define VALA_IS_CODE_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CODE_NODE))
+#define VALA_IS_CODE_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CODE_NODE))
+#define VALA_CODE_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_NODE, ValaCodeNodeClass))
 
+typedef struct _ValaCodeNode ValaCodeNode;
+typedef struct _ValaCodeNodeClass ValaCodeNodeClass;
+typedef struct _ValaCodeNodePrivate ValaCodeNodePrivate;
+
+#define VALA_TYPE_CODE_VISITOR (vala_code_visitor_get_type ())
+#define VALA_CODE_VISITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CODE_VISITOR, ValaCodeVisitor))
+#define VALA_CODE_VISITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CODE_VISITOR, ValaCodeVisitorClass))
+#define VALA_IS_CODE_VISITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CODE_VISITOR))
+#define VALA_IS_CODE_VISITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CODE_VISITOR))
+#define VALA_CODE_VISITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_VISITOR, ValaCodeVisitorClass))
+
+typedef struct _ValaCodeVisitor ValaCodeVisitor;
+typedef struct _ValaCodeVisitorClass ValaCodeVisitorClass;
+
+#define VALA_TYPE_SEMANTIC_ANALYZER (vala_semantic_analyzer_get_type ())
+#define VALA_SEMANTIC_ANALYZER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SEMANTIC_ANALYZER, ValaSemanticAnalyzer))
+#define VALA_SEMANTIC_ANALYZER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SEMANTIC_ANALYZER, ValaSemanticAnalyzerClass))
+#define VALA_IS_SEMANTIC_ANALYZER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SEMANTIC_ANALYZER))
+#define VALA_IS_SEMANTIC_ANALYZER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SEMANTIC_ANALYZER))
+#define VALA_SEMANTIC_ANALYZER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SEMANTIC_ANALYZER, ValaSemanticAnalyzerClass))
+
+typedef struct _ValaSemanticAnalyzer ValaSemanticAnalyzer;
+typedef struct _ValaSemanticAnalyzerClass ValaSemanticAnalyzerClass;
+
+#define VALA_TYPE_DATA_TYPE (vala_data_type_get_type ())
+#define VALA_DATA_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_DATA_TYPE, ValaDataType))
+#define VALA_DATA_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_DATA_TYPE, ValaDataTypeClass))
+#define VALA_IS_DATA_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_DATA_TYPE))
+#define VALA_IS_DATA_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_DATA_TYPE))
+#define VALA_DATA_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_DATA_TYPE, ValaDataTypeClass))
+
+typedef struct _ValaDataType ValaDataType;
+typedef struct _ValaDataTypeClass ValaDataTypeClass;
+
+#define VALA_TYPE_EXPRESSION (vala_expression_get_type ())
+#define VALA_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_EXPRESSION, ValaExpression))
+#define VALA_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_EXPRESSION, ValaExpressionClass))
+#define VALA_IS_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_EXPRESSION))
+#define VALA_IS_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_EXPRESSION))
+#define VALA_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_EXPRESSION, ValaExpressionClass))
+
+typedef struct _ValaExpression ValaExpression;
+typedef struct _ValaExpressionClass ValaExpressionClass;
+
+#define VALA_TYPE_SYMBOL (vala_symbol_get_type ())
+#define VALA_SYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SYMBOL, ValaSymbol))
+#define VALA_SYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SYMBOL, ValaSymbolClass))
+#define VALA_IS_SYMBOL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SYMBOL))
+#define VALA_IS_SYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SYMBOL))
+#define VALA_SYMBOL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SYMBOL, ValaSymbolClass))
+
+typedef struct _ValaSymbol ValaSymbol;
+typedef struct _ValaSymbolClass ValaSymbolClass;
+
+#define VALA_TYPE_LOCAL_VARIABLE (vala_local_variable_get_type ())
+#define VALA_LOCAL_VARIABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LOCAL_VARIABLE, ValaLocalVariable))
+#define VALA_LOCAL_VARIABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LOCAL_VARIABLE, ValaLocalVariableClass))
+#define VALA_IS_LOCAL_VARIABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LOCAL_VARIABLE))
+#define VALA_IS_LOCAL_VARIABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LOCAL_VARIABLE))
+#define VALA_LOCAL_VARIABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LOCAL_VARIABLE, ValaLocalVariableClass))
+
+typedef struct _ValaLocalVariable ValaLocalVariable;
+typedef struct _ValaLocalVariableClass ValaLocalVariableClass;
+
+#define VALA_TYPE_ATTRIBUTE (vala_attribute_get_type ())
+#define VALA_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ATTRIBUTE, ValaAttribute))
+#define VALA_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ATTRIBUTE, ValaAttributeClass))
+#define VALA_IS_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ATTRIBUTE))
+#define VALA_IS_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ATTRIBUTE))
+#define VALA_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ATTRIBUTE, ValaAttributeClass))
+
+typedef struct _ValaAttribute ValaAttribute;
+typedef struct _ValaAttributeClass ValaAttributeClass;
+typedef struct _ValaSymbolPrivate ValaSymbolPrivate;
+
+#define VALA_TYPE_NAMESPACE (vala_namespace_get_type ())
+#define VALA_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_NAMESPACE, ValaNamespace))
+#define VALA_NAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_NAMESPACE, ValaNamespaceClass))
+#define VALA_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_NAMESPACE))
+#define VALA_IS_NAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_NAMESPACE))
+#define VALA_NAMESPACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_NAMESPACE, ValaNamespaceClass))
+
+typedef struct _ValaNamespace ValaNamespace;
+typedef struct _ValaNamespaceClass ValaNamespaceClass;
+typedef struct _ValaNamespacePrivate ValaNamespacePrivate;
+
+#define VALA_TYPE_TYPESYMBOL (vala_typesymbol_get_type ())
+#define VALA_TYPESYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPESYMBOL, ValaTypeSymbol))
+#define VALA_TYPESYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_TYPESYMBOL, ValaTypeSymbolClass))
+#define VALA_IS_TYPESYMBOL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_TYPESYMBOL))
+#define VALA_IS_TYPESYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TYPESYMBOL))
+#define VALA_TYPESYMBOL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TYPESYMBOL, ValaTypeSymbolClass))
+
+typedef struct _ValaTypeSymbol ValaTypeSymbol;
+typedef struct _ValaTypeSymbolClass ValaTypeSymbolClass;
+
+#define VALA_TYPE_OBJECT_TYPE_SYMBOL (vala_object_type_symbol_get_type ())
+#define VALA_OBJECT_TYPE_SYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_OBJECT_TYPE_SYMBOL, ValaObjectTypeSymbol))
+#define VALA_OBJECT_TYPE_SYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_OBJECT_TYPE_SYMBOL, ValaObjectTypeSymbolClass))
+#define VALA_IS_OBJECT_TYPE_SYMBOL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_OBJECT_TYPE_SYMBOL))
+#define VALA_IS_OBJECT_TYPE_SYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_OBJECT_TYPE_SYMBOL))
+#define VALA_OBJECT_TYPE_SYMBOL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_OBJECT_TYPE_SYMBOL, ValaObjectTypeSymbolClass))
+
+typedef struct _ValaObjectTypeSymbol ValaObjectTypeSymbol;
+typedef struct _ValaObjectTypeSymbolClass ValaObjectTypeSymbolClass;
+
+#define VALA_TYPE_CLASS (vala_class_get_type ())
+#define VALA_CLASS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CLASS, ValaClass))
+#define VALA_CLASS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CLASS, ValaClassClass))
+#define VALA_IS_CLASS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CLASS))
+#define VALA_IS_CLASS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CLASS))
+#define VALA_CLASS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CLASS, ValaClassClass))
+
+typedef struct _ValaClass ValaClass;
+typedef struct _ValaClassClass ValaClassClass;
+
+#define VALA_TYPE_INTERFACE (vala_interface_get_type ())
+#define VALA_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_INTERFACE, ValaInterface))
+#define VALA_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_INTERFACE, ValaInterfaceClass))
+#define VALA_IS_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_INTERFACE))
+#define VALA_IS_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_INTERFACE))
+#define VALA_INTERFACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_INTERFACE, ValaInterfaceClass))
+
+typedef struct _ValaInterface ValaInterface;
+typedef struct _ValaInterfaceClass ValaInterfaceClass;
+
+#define VALA_TYPE_STRUCT (vala_struct_get_type ())
+#define VALA_STRUCT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_STRUCT, ValaStruct))
+#define VALA_STRUCT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_STRUCT, ValaStructClass))
+#define VALA_IS_STRUCT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_STRUCT))
+#define VALA_IS_STRUCT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_STRUCT))
+#define VALA_STRUCT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_STRUCT, ValaStructClass))
+
+typedef struct _ValaStruct ValaStruct;
+typedef struct _ValaStructClass ValaStructClass;
+
+#define VALA_TYPE_ENUM (vala_enum_get_type ())
+#define VALA_ENUM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ENUM, ValaEnum))
+#define VALA_ENUM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ENUM, ValaEnumClass))
+#define VALA_IS_ENUM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ENUM))
+#define VALA_IS_ENUM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ENUM))
+#define VALA_ENUM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ENUM, ValaEnumClass))
+
+typedef struct _ValaEnum ValaEnum;
+typedef struct _ValaEnumClass ValaEnumClass;
+
+#define VALA_TYPE_ERROR_DOMAIN (vala_error_domain_get_type ())
+#define VALA_ERROR_DOMAIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ERROR_DOMAIN, ValaErrorDomain))
+#define VALA_ERROR_DOMAIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ERROR_DOMAIN, ValaErrorDomainClass))
+#define VALA_IS_ERROR_DOMAIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ERROR_DOMAIN))
+#define VALA_IS_ERROR_DOMAIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ERROR_DOMAIN))
+#define VALA_ERROR_DOMAIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ERROR_DOMAIN, ValaErrorDomainClass))
+
+typedef struct _ValaErrorDomain ValaErrorDomain;
+typedef struct _ValaErrorDomainClass ValaErrorDomainClass;
+
+#define VALA_TYPE_DELEGATE (vala_delegate_get_type ())
+#define VALA_DELEGATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_DELEGATE, ValaDelegate))
+#define VALA_DELEGATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_DELEGATE, ValaDelegateClass))
+#define VALA_IS_DELEGATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_DELEGATE))
+#define VALA_IS_DELEGATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_DELEGATE))
+#define VALA_DELEGATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_DELEGATE, ValaDelegateClass))
+
+typedef struct _ValaDelegate ValaDelegate;
+typedef struct _ValaDelegateClass ValaDelegateClass;
+
+#define VALA_TYPE_MEMBER (vala_member_get_type ())
+#define VALA_MEMBER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_MEMBER, ValaMember))
+#define VALA_MEMBER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_MEMBER, ValaMemberClass))
+#define VALA_IS_MEMBER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_MEMBER))
+#define VALA_IS_MEMBER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_MEMBER))
+#define VALA_MEMBER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_MEMBER, ValaMemberClass))
+
+typedef struct _ValaMember ValaMember;
+typedef struct _ValaMemberClass ValaMemberClass;
+
+#define VALA_TYPE_CONSTANT (vala_constant_get_type ())
+#define VALA_CONSTANT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CONSTANT, ValaConstant))
+#define VALA_CONSTANT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CONSTANT, ValaConstantClass))
+#define VALA_IS_CONSTANT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CONSTANT))
+#define VALA_IS_CONSTANT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CONSTANT))
+#define VALA_CONSTANT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CONSTANT, ValaConstantClass))
+
+typedef struct _ValaConstant ValaConstant;
+typedef struct _ValaConstantClass ValaConstantClass;
+
+#define VALA_TYPE_FIELD (vala_field_get_type ())
+#define VALA_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_FIELD, ValaField))
+#define VALA_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_FIELD, ValaFieldClass))
+#define VALA_IS_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_FIELD))
+#define VALA_IS_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_FIELD))
+#define VALA_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_FIELD, ValaFieldClass))
+
+typedef struct _ValaField ValaField;
+typedef struct _ValaFieldClass ValaFieldClass;
+
+#define VALA_TYPE_METHOD (vala_method_get_type ())
+#define VALA_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_METHOD, ValaMethod))
+#define VALA_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_METHOD, ValaMethodClass))
+#define VALA_IS_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_METHOD))
+#define VALA_IS_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_METHOD))
+#define VALA_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_METHOD, ValaMethodClass))
+
+typedef struct _ValaMethod ValaMethod;
+typedef struct _ValaMethodClass ValaMethodClass;
+
+#define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
+#define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
+#define VALA_SOURCE_REFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReferenceClass))
+#define VALA_IS_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SOURCE_REFERENCE))
+#define VALA_IS_SOURCE_REFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SOURCE_REFERENCE))
+#define VALA_SOURCE_REFERENCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReferenceClass))
+
+typedef struct _ValaSourceReference ValaSourceReference;
+typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+
+#define VALA_TYPE_SYMBOL_ACCESSIBILITY (vala_symbol_accessibility_get_type ())
+
+#define VALA_TYPE_SCOPE (vala_scope_get_type ())
+#define VALA_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SCOPE, ValaScope))
+#define VALA_SCOPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SCOPE, ValaScopeClass))
+#define VALA_IS_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_SCOPE))
+#define VALA_IS_SCOPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SCOPE))
+#define VALA_SCOPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SCOPE, ValaScopeClass))
+
+typedef struct _ValaScope ValaScope;
+typedef struct _ValaScopeClass ValaScopeClass;
+
+#define TYPE_MEMBER_BINDING (member_binding_get_type ())
+
+#define VALA_TYPE_CREATION_METHOD (vala_creation_method_get_type ())
+#define VALA_CREATION_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CREATION_METHOD, ValaCreationMethod))
+#define VALA_CREATION_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CREATION_METHOD, ValaCreationMethodClass))
+#define VALA_IS_CREATION_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CREATION_METHOD))
+#define VALA_IS_CREATION_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CREATION_METHOD))
+#define VALA_CREATION_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CREATION_METHOD, ValaCreationMethodClass))
+
+typedef struct _ValaCreationMethod ValaCreationMethod;
+typedef struct _ValaCreationMethodClass ValaCreationMethodClass;
+
+/**
+ * Represents a part of the parsed source code.
+ *
+ * Code nodes get created by the parser and are used throughout the whole
+ * compilation process.
+ */
+struct _ValaCodeNode {
+	GTypeInstance parent_instance;
+	volatile int ref_count;
+	ValaCodeNodePrivate * priv;
+	GList* attributes;
+};
+
+struct _ValaCodeNodeClass {
+	GTypeClass parent_class;
+	void (*finalize) (ValaCodeNode *self);
+	void (*accept) (ValaCodeNode* self, ValaCodeVisitor* visitor);
+	void (*accept_children) (ValaCodeNode* self, ValaCodeVisitor* visitor);
+	gboolean (*check) (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
+	void (*replace_type) (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
+	void (*replace_expression) (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node);
+	char* (*to_string) (ValaCodeNode* self);
+	void (*get_defined_variables) (ValaCodeNode* self, GeeCollection* collection);
+	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
+};
+
+/**
+ * Represents a node in the symbol tree.
+ */
+struct _ValaSymbol {
+	ValaCodeNode parent_instance;
+	ValaSymbolPrivate * priv;
+};
+
+struct _ValaSymbolClass {
+	ValaCodeNodeClass parent_class;
+	char* (*get_cprefix) (ValaSymbol* self);
+	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
+	char* (*get_lower_case_cprefix) (ValaSymbol* self);
+	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
+};
+
+/**
+ * Represents a namespace declaration in the source code.
+ */
+struct _ValaNamespace {
+	ValaSymbol parent_instance;
+	ValaNamespacePrivate * priv;
+};
+
+struct _ValaNamespaceClass {
+	ValaSymbolClass parent_class;
+};
 
 struct _ValaNamespacePrivate {
 	GeeList* classes;
@@ -63,16 +344,138 @@ struct _ValaNamespacePrivate {
 	GeeList* namespaces;
 };
 
+typedef enum  {
+	VALA_SYMBOL_ACCESSIBILITY_PRIVATE,
+	VALA_SYMBOL_ACCESSIBILITY_INTERNAL,
+	VALA_SYMBOL_ACCESSIBILITY_PROTECTED,
+	VALA_SYMBOL_ACCESSIBILITY_PUBLIC
+} ValaSymbolAccessibility;
+
+typedef enum  {
+	MEMBER_BINDING_INSTANCE,
+	MEMBER_BINDING_CLASS,
+	MEMBER_BINDING_STATIC
+} MemberBinding;
+
+
+
+gpointer vala_code_node_ref (gpointer instance);
+void vala_code_node_unref (gpointer instance);
+GParamSpec* vala_param_spec_code_node (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_code_node (GValue* value, gpointer v_object);
+gpointer vala_value_get_code_node (const GValue* value);
+GType vala_code_node_get_type (void);
+gpointer vala_code_visitor_ref (gpointer instance);
+void vala_code_visitor_unref (gpointer instance);
+GParamSpec* vala_param_spec_code_visitor (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_code_visitor (GValue* value, gpointer v_object);
+gpointer vala_value_get_code_visitor (const GValue* value);
+GType vala_code_visitor_get_type (void);
+GType vala_semantic_analyzer_get_type (void);
+GType vala_data_type_get_type (void);
+GType vala_expression_get_type (void);
+GType vala_symbol_get_type (void);
+GType vala_local_variable_get_type (void);
+GType vala_attribute_get_type (void);
+GType vala_namespace_get_type (void);
+GType vala_typesymbol_get_type (void);
+GType vala_object_type_symbol_get_type (void);
+GType vala_class_get_type (void);
+GType vala_interface_get_type (void);
+GType vala_struct_get_type (void);
+GType vala_enum_get_type (void);
+GType vala_error_domain_get_type (void);
+GType vala_delegate_get_type (void);
+GType vala_member_get_type (void);
+GType vala_constant_get_type (void);
+GType vala_field_get_type (void);
+GType vala_method_get_type (void);
 #define VALA_NAMESPACE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_NAMESPACE, ValaNamespacePrivate))
 enum  {
 	VALA_NAMESPACE_DUMMY_PROPERTY
 };
+gpointer vala_source_reference_ref (gpointer instance);
+void vala_source_reference_unref (gpointer instance);
+GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_source_reference (GValue* value, gpointer v_object);
+gpointer vala_value_get_source_reference (const GValue* value);
+GType vala_source_reference_get_type (void);
+ValaSymbol* vala_symbol_new (const char* name, ValaSourceReference* source_reference);
+ValaSymbol* vala_symbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
+GType vala_symbol_accessibility_get_type (void);
+void vala_symbol_set_access (ValaSymbol* self, ValaSymbolAccessibility value);
+ValaNamespace* vala_namespace_new (const char* name, ValaSourceReference* source_reference);
+ValaNamespace* vala_namespace_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
+ValaNamespace* vala_namespace_new (const char* name, ValaSourceReference* source_reference);
+gpointer vala_scope_ref (gpointer instance);
+void vala_scope_unref (gpointer instance);
+GParamSpec* vala_param_spec_scope (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_scope (GValue* value, gpointer v_object);
+gpointer vala_value_get_scope (const GValue* value);
+GType vala_scope_get_type (void);
+ValaScope* vala_symbol_get_scope (ValaSymbol* self);
+ValaSymbol* vala_scope_lookup (ValaScope* self, const char* name);
+const char* vala_symbol_get_name (ValaSymbol* self);
+gboolean vala_symbol_get_external_package (ValaSymbol* self);
+ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
+void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
+GeeList* vala_namespace_get_namespaces (ValaNamespace* self);
+void vala_namespace_add_namespace (ValaNamespace* self, ValaNamespace* ns);
+GeeList* vala_namespace_get_classes (ValaNamespace* self);
+void vala_namespace_add_class (ValaNamespace* self, ValaClass* cl);
+GeeList* vala_namespace_get_structs (ValaNamespace* self);
+void vala_namespace_add_struct (ValaNamespace* self, ValaStruct* st);
+GeeList* vala_namespace_get_interfaces (ValaNamespace* self);
+void vala_namespace_add_interface (ValaNamespace* self, ValaInterface* iface);
+GeeList* vala_namespace_get_delegates (ValaNamespace* self);
+void vala_namespace_add_delegate (ValaNamespace* self, ValaDelegate* d);
+GeeList* vala_namespace_get_enums (ValaNamespace* self);
+void vala_namespace_add_enum (ValaNamespace* self, ValaEnum* en);
+GeeList* vala_namespace_get_error_domains (ValaNamespace* self);
+void vala_namespace_add_error_domain (ValaNamespace* self, ValaErrorDomain* edomain);
+GeeList* vala_namespace_get_constants (ValaNamespace* self);
+void vala_namespace_add_constant (ValaNamespace* self, ValaConstant* constant);
+GeeList* vala_namespace_get_fields (ValaNamespace* self);
+void vala_namespace_add_field (ValaNamespace* self, ValaField* f);
+GeeList* vala_namespace_get_methods (ValaNamespace* self);
+void vala_namespace_add_method (ValaNamespace* self, ValaMethod* m);
+void vala_scope_add (ValaScope* self, const char* name, ValaSymbol* sym);
+ValaSymbolAccessibility vala_symbol_get_access (ValaSymbol* self);
+void vala_scope_remove (ValaScope* self, const char* name);
+void vala_namespace_remove_struct (ValaNamespace* self, ValaStruct* st);
+GType member_binding_get_type (void);
+MemberBinding vala_field_get_binding (ValaField* self);
+void vala_report_error (ValaSourceReference* source, const char* message);
+void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
+GType vala_creation_method_get_type (void);
+MemberBinding vala_method_get_binding (ValaMethod* self);
+void vala_code_visitor_visit_namespace (ValaCodeVisitor* self, ValaNamespace* ns);
 static void vala_namespace_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
+ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self);
+char* vala_symbol_get_cprefix (ValaSymbol* self);
 static char* vala_namespace_real_get_cprefix (ValaSymbol* base);
+GeeList* vala_namespace_get_cprefixes (ValaNamespace* self);
+void vala_namespace_add_cprefix (ValaNamespace* self, const char* cprefix);
+char* vala_symbol_get_lower_case_cprefix (ValaSymbol* self);
+char* vala_symbol_camel_case_to_lower_case (const char* camel_case);
 static char* vala_namespace_real_get_lower_case_cprefix (ValaSymbol* base);
+void vala_namespace_set_lower_case_cprefix (ValaNamespace* self, const char* cprefix);
 static GeeList* vala_namespace_real_get_cheader_filenames (ValaSymbol* base);
+GeeList* vala_symbol_get_cheader_filenames (ValaSymbol* self);
+char* vala_namespace_get_cheader_filename (ValaNamespace* self);
+void vala_namespace_set_cheader_filename (ValaNamespace* self, const char* cheader_filename);
+void vala_namespace_add_cheader_filename (ValaNamespace* self, const char* cheader_filename);
+gboolean vala_attribute_has_argument (ValaAttribute* self, const char* name);
+char* vala_attribute_get_string (ValaAttribute* self, const char* name);
 static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAttribute* a);
+const char* vala_attribute_get_name (ValaAttribute* self);
+void vala_namespace_process_attributes (ValaNamespace* self);
+gboolean vala_code_node_get_checked (ValaCodeNode* self);
+gboolean vala_code_node_get_error (ValaCodeNode* self);
+void vala_code_node_set_checked (ValaCodeNode* self, gboolean value);
+gboolean vala_code_node_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
 static gboolean vala_namespace_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 static gpointer vala_namespace_parent_class = NULL;
 static void vala_namespace_finalize (ValaCodeNode* obj);
@@ -897,6 +1300,18 @@ void vala_namespace_set_cheader_filename (ValaNamespace* self, const char* chead
 }
 
 
+/**
+ * Adds a C header filename of this namespace.
+ *
+ * @param cheader_filename header filename
+ */
+void vala_namespace_add_cheader_filename (ValaNamespace* self, const char* cheader_filename) {
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (cheader_filename != NULL);
+	gee_collection_add ((GeeCollection*) self->priv->cheader_filenames, cheader_filename);
+}
+
+
 static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAttribute* a) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (a != NULL);
