@@ -20,24 +20,15 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include <vapigen/valavapigen.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <vala.h>
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <vala/valacodecontext.h>
-#include <vala/valareport.h>
-#include <stdio.h>
-#include <vala/valasourcefile.h>
 #include <glib/gstdio.h>
-#include <vala/valasourcereference.h>
-#include <vala/valaparser.h>
-#include <vala/valasymbolresolver.h>
-#include <vala/valasemanticanalyzer.h>
-#include <gee/iterable.h>
-#include <gee/iterator.h>
-#include <vala/valacodewriter.h>
+#include <gee.h>
 #include <config.h>
-#include "vapigen/valagirparser.h"
-#include "vapigen/valagidlparser.h"
 
 
 #define VALA_TYPE_VAPI_GEN (vala_vapi_gen_get_type ())
@@ -51,6 +42,26 @@ typedef struct _ValaVAPIGen ValaVAPIGen;
 typedef struct _ValaVAPIGenClass ValaVAPIGenClass;
 typedef struct _ValaVAPIGenPrivate ValaVAPIGenPrivate;
 
+#define VALA_TYPE_GIR_PARSER (vala_gir_parser_get_type ())
+#define VALA_GIR_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_GIR_PARSER, ValaGirParser))
+#define VALA_GIR_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_GIR_PARSER, ValaGirParserClass))
+#define VALA_IS_GIR_PARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_GIR_PARSER))
+#define VALA_IS_GIR_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_GIR_PARSER))
+#define VALA_GIR_PARSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_GIR_PARSER, ValaGirParserClass))
+
+typedef struct _ValaGirParser ValaGirParser;
+typedef struct _ValaGirParserClass ValaGirParserClass;
+
+#define VALA_TYPE_GIDL_PARSER (vala_gidl_parser_get_type ())
+#define VALA_GIDL_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_GIDL_PARSER, ValaGIdlParser))
+#define VALA_GIDL_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_GIDL_PARSER, ValaGIdlParserClass))
+#define VALA_IS_GIDL_PARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_GIDL_PARSER))
+#define VALA_IS_GIDL_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_GIDL_PARSER))
+#define VALA_GIDL_PARSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_GIDL_PARSER, ValaGIdlParserClass))
+
+typedef struct _ValaGIdlParser ValaGIdlParser;
+typedef struct _ValaGIdlParserClass ValaGIdlParserClass;
+
 struct _ValaVAPIGen {
 	GObject parent_instance;
 	ValaVAPIGenPrivate * priv;
@@ -60,71 +71,69 @@ struct _ValaVAPIGenClass {
 	GObjectClass parent_class;
 };
 
-
-
-static char* string_substring (const char* self, glong offset, glong len);
 struct _ValaVAPIGenPrivate {
 	ValaCodeContext* context;
 };
 
+
+
+GType vala_vapi_gen_get_type (void);
 #define VALA_VAPI_GEN_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_VAPI_GEN, ValaVAPIGenPrivate))
 enum  {
 	VALA_VAPI_GEN_DUMMY_PROPERTY
 };
+static char* vala_vapi_gen_directory;
 static char* vala_vapi_gen_directory = NULL;
+static gboolean vala_vapi_gen_version;
 static gboolean vala_vapi_gen_version = FALSE;
+static gboolean vala_vapi_gen_quiet_mode;
 static gboolean vala_vapi_gen_quiet_mode = FALSE;
+static char** vala_vapi_gen_sources;
 static char** vala_vapi_gen_sources = NULL;
+static char** vala_vapi_gen_vapi_directories;
 static char** vala_vapi_gen_vapi_directories = NULL;
+static char* vala_vapi_gen_library;
 static char* vala_vapi_gen_library = NULL;
+static char** vala_vapi_gen_packages;
 static char** vala_vapi_gen_packages = NULL;
+static char* vala_vapi_gen_metadata_filename;
 static char* vala_vapi_gen_metadata_filename = NULL;
 static gint vala_vapi_gen_quit (ValaVAPIGen* self);
 static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg);
 static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, int* result_length1);
+ValaGirParser* vala_gir_parser_new (void);
+ValaGirParser* vala_gir_parser_construct (GType object_type);
+GType vala_gir_parser_get_type (void);
+void vala_gir_parser_parse_metadata (ValaGirParser* self, const char* metadata_filename);
+void vala_gir_parser_parse (ValaGirParser* self, ValaCodeContext* context);
+ValaGIdlParser* vala_gidl_parser_new (void);
+ValaGIdlParser* vala_gidl_parser_construct (GType object_type);
+GType vala_gidl_parser_get_type (void);
+void vala_gidl_parser_parse (ValaGIdlParser* self, ValaCodeContext* context);
+const char* vala_gir_parser_get_package_name (ValaGirParser* self);
 static gint vala_vapi_gen_run (ValaVAPIGen* self);
+ValaVAPIGen* vala_vapi_gen_new (void);
+ValaVAPIGen* vala_vapi_gen_construct (GType object_type);
 static gint vala_vapi_gen_main (char** args, int args_length1);
-static ValaVAPIGen* vala_vapi_gen_construct (GType object_type);
-static ValaVAPIGen* vala_vapi_gen_new (void);
+ValaVAPIGen* vala_vapi_gen_new (void);
 static gpointer vala_vapi_gen_parent_class = NULL;
 static void vala_vapi_gen_finalize (GObject* obj);
-static GType vala_vapi_gen_get_type (void);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static gint _vala_array_length (gpointer array);
 
 static const GOptionEntry VALA_VAPI_GEN_options[] = {{"vapidir", (gchar) 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_vapi_directories, "Look for package bindings in DIRECTORY", "DIRECTORY..."}, {"pkg", (gchar) 0, 0, G_OPTION_ARG_STRING_ARRAY, &vala_vapi_gen_packages, "Include binding for PACKAGE", "PACKAGE..."}, {"library", (gchar) 0, 0, G_OPTION_ARG_STRING, &vala_vapi_gen_library, "Library name", "NAME"}, {"metadata", (gchar) 0, 0, G_OPTION_ARG_FILENAME, &vala_vapi_gen_metadata_filename, "Metadata filename", "FILE"}, {"directory", 'd', 0, G_OPTION_ARG_FILENAME, &vala_vapi_gen_directory, "Output directory", "DIRECTORY"}, {"version", (gchar) 0, 0, G_OPTION_ARG_NONE, &vala_vapi_gen_version, "Display version number", NULL}, {"quiet", 'q', 0, G_OPTION_ARG_NONE, &vala_vapi_gen_quiet_mode, "Do not print messages to the console", NULL}, {"", (gchar) 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_sources, NULL, "FILE..."}, {NULL}};
 
 
-static char* string_substring (const char* self, glong offset, glong len) {
-	glong string_length;
-	const char* start;
-	g_return_val_if_fail (self != NULL, NULL);
-	string_length = g_utf8_strlen (self, -1);
-	if (offset < 0) {
-		offset = string_length + offset;
-		g_return_val_if_fail (offset >= 0, NULL);
-	} else {
-		g_return_val_if_fail (offset <= string_length, NULL);
-	}
-	if (len < 0) {
-		len = string_length - offset;
-	}
-	g_return_val_if_fail ((offset + len) <= string_length, NULL);
-	start = g_utf8_offset_to_pointer (self, offset);
-	return g_strndup (start, ((gchar*) g_utf8_offset_to_pointer (start, len)) - ((gchar*) start));
-}
-
-
 static gint vala_vapi_gen_quit (ValaVAPIGen* self) {
 	g_return_val_if_fail (self != NULL, 0);
-	if (vala_report_get_errors () == 0) {
+	if (vala_report_get_errors (vala_code_context_get_report (self->priv->context)) == 0) {
 		if (!vala_vapi_gen_quiet_mode) {
-			fprintf (stdout, "Generation succeeded - %d warning(s)\n", vala_report_get_warnings ());
+			fprintf (stdout, "Generation succeeded - %d warning(s)\n", vala_report_get_warnings (vala_code_context_get_report (self->priv->context)));
 		}
 		return 0;
 	} else {
 		if (!vala_vapi_gen_quiet_mode) {
-			fprintf (stdout, "Generation failed: %d error(s), %d warning(s)\n", vala_report_get_errors (), vala_report_get_warnings ());
+			fprintf (stdout, "Generation failed: %d error(s), %d warning(s)\n", vala_report_get_errors (vala_code_context_get_report (self->priv->context)), vala_report_get_warnings (vala_code_context_get_report (self->priv->context)));
 		}
 		return 1;
 	}
@@ -207,6 +216,26 @@ static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, in
 }
 
 
+static char* string_substring (const char* self, glong offset, glong len) {
+	glong string_length;
+	const char* start;
+	g_return_val_if_fail (self != NULL, NULL);
+	string_length = g_utf8_strlen (self, -1);
+	if (offset < 0) {
+		offset = string_length + offset;
+		g_return_val_if_fail (offset >= 0, NULL);
+	} else {
+		g_return_val_if_fail (offset <= string_length, NULL);
+	}
+	if (len < 0) {
+		len = string_length - offset;
+	}
+	g_return_val_if_fail ((offset + len) <= string_length, NULL);
+	start = g_utf8_offset_to_pointer (self, offset);
+	return g_strndup (start, ((gchar*) g_utf8_offset_to_pointer (start, len)) - ((gchar*) start));
+}
+
+
 static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 	ValaCodeContext* _tmp0;
 	char** _tmp15;
@@ -215,10 +244,12 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 	ValaGIdlParser* gidlparser;
 	ValaSymbolResolver* resolver;
 	ValaSemanticAnalyzer* analyzer;
-	gint _tmp26;
+	gboolean _tmp22;
+	gint _tmp29;
 	g_return_val_if_fail (self != NULL, 0);
 	_tmp0 = NULL;
 	self->priv->context = (_tmp0 = vala_code_context_new (), (self->priv->context == NULL) ? NULL : (self->priv->context = (vala_code_context_unref (self->priv->context), NULL)), _tmp0);
+	vala_code_context_push (self->priv->context);
 	/* default package */
 	if (!vala_vapi_gen_add_package (self, "glib-2.0")) {
 		vala_report_error (NULL, "glib-2.0 not found in specified Vala API directories");
@@ -316,7 +347,7 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 		_tmp10 = NULL;
 		vala_vapi_gen_packages = (_tmp10 = NULL, vala_vapi_gen_packages = (_vala_array_free (vala_vapi_gen_packages, _vala_array_length (vala_vapi_gen_packages), (GDestroyNotify) g_free), NULL), _tmp10);
 	}
-	if (vala_report_get_errors () > 0) {
+	if (vala_report_get_errors (vala_code_context_get_report (self->priv->context)) > 0) {
 		return vala_vapi_gen_quit (self);
 	}
 	{
@@ -348,12 +379,12 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 	}
 	_tmp15 = NULL;
 	vala_vapi_gen_sources = (_tmp15 = NULL, vala_vapi_gen_sources = (_vala_array_free (vala_vapi_gen_sources, _vala_array_length (vala_vapi_gen_sources), (GDestroyNotify) g_free), NULL), _tmp15);
-	if (vala_report_get_errors () > 0) {
+	if (vala_report_get_errors (vala_code_context_get_report (self->priv->context)) > 0) {
 		return vala_vapi_gen_quit (self);
 	}
 	parser = vala_parser_new ();
 	vala_parser_parse (parser, self->priv->context);
-	if (vala_report_get_errors () > 0) {
+	if (vala_report_get_errors (vala_code_context_get_report (self->priv->context)) > 0) {
 		gint _tmp17;
 		return (_tmp17 = vala_vapi_gen_quit (self), (parser == NULL) ? NULL : (parser = (vala_code_visitor_unref (parser), NULL)), _tmp17);
 	}
@@ -362,41 +393,54 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 		vala_gir_parser_parse_metadata (girparser, vala_vapi_gen_metadata_filename);
 	}
 	vala_gir_parser_parse (girparser, self->priv->context);
-	if (vala_report_get_errors () > 0) {
+	if (vala_report_get_errors (vala_code_context_get_report (self->priv->context)) > 0) {
 		gint _tmp18;
 		return (_tmp18 = vala_vapi_gen_quit (self), (parser == NULL) ? NULL : (parser = (vala_code_visitor_unref (parser), NULL)), (girparser == NULL) ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL)), _tmp18);
 	}
 	gidlparser = vala_gidl_parser_new ();
 	vala_gidl_parser_parse (gidlparser, self->priv->context);
-	if (vala_report_get_errors () > 0) {
+	if (vala_report_get_errors (vala_code_context_get_report (self->priv->context)) > 0) {
 		gint _tmp19;
 		return (_tmp19 = vala_vapi_gen_quit (self), (parser == NULL) ? NULL : (parser = (vala_code_visitor_unref (parser), NULL)), (girparser == NULL) ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL)), (gidlparser == NULL) ? NULL : (gidlparser = (vala_code_visitor_unref (gidlparser), NULL)), _tmp19);
 	}
 	resolver = vala_symbol_resolver_new ();
 	vala_symbol_resolver_resolve (resolver, self->priv->context);
-	if (vala_report_get_errors () > 0) {
+	if (vala_report_get_errors (vala_code_context_get_report (self->priv->context)) > 0) {
 		gint _tmp20;
 		return (_tmp20 = vala_vapi_gen_quit (self), (parser == NULL) ? NULL : (parser = (vala_code_visitor_unref (parser), NULL)), (girparser == NULL) ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL)), (gidlparser == NULL) ? NULL : (gidlparser = (vala_code_visitor_unref (gidlparser), NULL)), (resolver == NULL) ? NULL : (resolver = (vala_code_visitor_unref (resolver), NULL)), _tmp20);
 	}
 	analyzer = vala_semantic_analyzer_new ();
 	vala_semantic_analyzer_analyze (analyzer, self->priv->context);
-	if (vala_report_get_errors () > 0) {
+	if (vala_report_get_errors (vala_code_context_get_report (self->priv->context)) > 0) {
 		gint _tmp21;
 		return (_tmp21 = vala_vapi_gen_quit (self), (parser == NULL) ? NULL : (parser = (vala_code_visitor_unref (parser), NULL)), (girparser == NULL) ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL)), (gidlparser == NULL) ? NULL : (gidlparser = (vala_code_visitor_unref (gidlparser), NULL)), (resolver == NULL) ? NULL : (resolver = (vala_code_visitor_unref (resolver), NULL)), (analyzer == NULL) ? NULL : (analyzer = (vala_code_visitor_unref (analyzer), NULL)), _tmp21);
 	}
+	_tmp22 = FALSE;
+	if (vala_vapi_gen_library == NULL) {
+		_tmp22 = vala_gir_parser_get_package_name (girparser) != NULL;
+	} else {
+		_tmp22 = FALSE;
+	}
+	if (_tmp22) {
+		char* _tmp24;
+		const char* _tmp23;
+		_tmp24 = NULL;
+		_tmp23 = NULL;
+		vala_vapi_gen_library = (_tmp24 = (_tmp23 = vala_gir_parser_get_package_name (girparser), (_tmp23 == NULL) ? NULL : g_strdup (_tmp23)), vala_vapi_gen_library = (g_free (vala_vapi_gen_library), NULL), _tmp24);
+	}
 	if (vala_vapi_gen_library != NULL) {
 		ValaCodeWriter* interface_writer;
-		char* _tmp24;
-		char* _tmp25;
+		char* _tmp27;
+		char* _tmp28;
 		/* interface writer ignores external packages*/
 		{
-			GeeList* _tmp22;
-			GeeIterator* _tmp23;
+			GeeList* _tmp25;
+			GeeIterator* _tmp26;
 			GeeIterator* _file_it;
 			/* interface writer ignores external packages*/
-			_tmp22 = NULL;
-			_tmp23 = NULL;
-			_file_it = (_tmp23 = gee_iterable_iterator ((GeeIterable*) (_tmp22 = vala_code_context_get_source_files (self->priv->context))), (_tmp22 == NULL) ? NULL : (_tmp22 = (gee_collection_object_unref (_tmp22), NULL)), _tmp23);
+			_tmp25 = NULL;
+			_tmp26 = NULL;
+			_file_it = (_tmp26 = gee_iterable_iterator ((GeeIterable*) (_tmp25 = vala_code_context_get_source_files (self->priv->context))), (_tmp25 == NULL) ? NULL : (_tmp25 = (gee_collection_object_unref (_tmp25), NULL)), _tmp26);
 			/* interface writer ignores external packages*/
 			while (gee_iterator_next (_file_it)) {
 				ValaSourceFile* file;
@@ -410,14 +454,14 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 			(_file_it == NULL) ? NULL : (_file_it = (gee_collection_object_unref (_file_it), NULL));
 		}
 		interface_writer = vala_code_writer_new (FALSE);
-		_tmp24 = NULL;
-		vala_code_writer_write_file (interface_writer, self->priv->context, _tmp24 = g_strdup_printf ("%s.vapi", vala_vapi_gen_library));
-		_tmp24 = (g_free (_tmp24), NULL);
-		_tmp25 = NULL;
-		vala_vapi_gen_library = (_tmp25 = NULL, vala_vapi_gen_library = (g_free (vala_vapi_gen_library), NULL), _tmp25);
+		_tmp27 = NULL;
+		vala_code_writer_write_file (interface_writer, self->priv->context, _tmp27 = g_strdup_printf ("%s.vapi", vala_vapi_gen_library));
+		_tmp27 = (g_free (_tmp27), NULL);
+		_tmp28 = NULL;
+		vala_vapi_gen_library = (_tmp28 = NULL, vala_vapi_gen_library = (g_free (vala_vapi_gen_library), NULL), _tmp28);
 		(interface_writer == NULL) ? NULL : (interface_writer = (vala_code_visitor_unref (interface_writer), NULL));
 	}
-	return (_tmp26 = vala_vapi_gen_quit (self), (parser == NULL) ? NULL : (parser = (vala_code_visitor_unref (parser), NULL)), (girparser == NULL) ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL)), (gidlparser == NULL) ? NULL : (gidlparser = (vala_code_visitor_unref (gidlparser), NULL)), (resolver == NULL) ? NULL : (resolver = (vala_code_visitor_unref (resolver), NULL)), (analyzer == NULL) ? NULL : (analyzer = (vala_code_visitor_unref (analyzer), NULL)), _tmp26);
+	return (_tmp29 = vala_vapi_gen_quit (self), (parser == NULL) ? NULL : (parser = (vala_code_visitor_unref (parser), NULL)), (girparser == NULL) ? NULL : (girparser = (vala_code_visitor_unref (girparser), NULL)), (gidlparser == NULL) ? NULL : (gidlparser = (vala_code_visitor_unref (gidlparser), NULL)), (resolver == NULL) ? NULL : (resolver = (vala_code_visitor_unref (resolver), NULL)), (analyzer == NULL) ? NULL : (analyzer = (vala_code_visitor_unref (analyzer), NULL)), _tmp29);
 }
 
 
@@ -479,14 +523,14 @@ int main (int argc, char ** argv) {
 }
 
 
-static ValaVAPIGen* vala_vapi_gen_construct (GType object_type) {
+ValaVAPIGen* vala_vapi_gen_construct (GType object_type) {
 	ValaVAPIGen * self;
 	self = g_object_newv (object_type, 0, NULL);
 	return self;
 }
 
 
-static ValaVAPIGen* vala_vapi_gen_new (void) {
+ValaVAPIGen* vala_vapi_gen_new (void) {
 	return vala_vapi_gen_construct (VALA_TYPE_VAPI_GEN);
 }
 
@@ -511,7 +555,7 @@ static void vala_vapi_gen_finalize (GObject* obj) {
 }
 
 
-static GType vala_vapi_gen_get_type (void) {
+GType vala_vapi_gen_get_type (void) {
 	static GType vala_vapi_gen_type_id = 0;
 	if (vala_vapi_gen_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaVAPIGenClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_vapi_gen_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVAPIGen), 0, (GInstanceInitFunc) vala_vapi_gen_instance_init, NULL };
